/*
 *  subproc.hpp
 *
 *  Run program as a subprocess.
 *
 *  Joris van Rantwijk 2024
 */

#ifndef PUZZLEFW_SUBPROC_H_
#define PUZZLEFW_SUBPROC_H_

#include <string>
#include <vector>


namespace puzzlefw {

/**
 * Run the specified program in a subprocess.
 *
 * The argument "path" specifies the full path of the target program.
 * This string also becomes the value of "argv[0]".
 *
 * The argument "args" specifies a list of optional additional arguments
 * ("argv[1]" and further).
 *
 * The subprocess closes non-standard file descriptors before executing
 * the program.
 *
 * This function waits (blocks) until the subprocess ends.
 * It returns the termination status of the subprocess.
 */
int run_subprocess(std::string path, std::vector<std::string> args);

}  // namespace puzzlefw

#endif  // PUZZLEFW_SUBPROC_H_
